Update for 0.9.2
diff --git a/docs/source/predictionio.rst b/docs/source/predictionio.rst
index 0dd090e..99ecbeb 100644
--- a/docs/source/predictionio.rst
+++ b/docs/source/predictionio.rst
@@ -59,9 +59,10 @@
 predictionio.FileExporter Class
 -------------------------------
 
+.. versionadded:: 0.9.2
 .. autoclass:: FileExporter
    :members:
-   
+
 
 predictionio SDK Usage Notes
 -------------------------
@@ -89,8 +90,7 @@
    In some cases you may not care whether the request is successful for performance or application-specific reasons, then you can simply skip step 2.
 
 .. note::
-   If you do care about the request status or need to get the return data, then at a later time you will need to call :meth:`~Client.aresp` with the AsyncRequest object returned in step 1.
-   Please refer to the documentation of :ref:`asynchronous request methods <async-methods-label>` for more details.
+   If you do care about the request status or need to get the return data, then at a later time you will need to call :meth:`~AsyncRequest.get_response` with the AsyncRequest object returned in step 1.
 
 For example, the following code first generates an asynchronous request to
 retrieve recommendations, then get the result at later time::
@@ -135,6 +135,8 @@
 Batch Import Data with FileExporter and "pio import"
 ^^^^^^^^^^^^^^^^^^^^^^^
 
+.. versionadded:: 0.9.2
+
 You can use FileExporter to create events and write to a JSON file which can
 be used by "pio import". Pleas see `Importing Data in Batch <http://docs.prediction.io/datacollection/batchimport/>`_ for more details.
 
diff --git a/setup.py b/setup.py
index 24bfc03..15163d1 100644
--- a/setup.py
+++ b/setup.py
@@ -10,7 +10,7 @@
 
 setup(
     name='PredictionIO',
-    version="0.8.3",
+    version="0.9.2",
     author=__author__,
     author_email=__email__,
     packages=['predictionio'],
diff --git a/predictionio/__init__.py b/predictionio/__init__.py
index 280fc65..8f40a4f 100644
--- a/predictionio/__init__.py
+++ b/predictionio/__init__.py
@@ -5,7 +5,7 @@
 """
 
 
-__version__ = "0.8.3"
+__version__ = "0.9.2"
 
 # import deprecated libraries.
 from predictionio.obsolete import Client
@@ -489,7 +489,7 @@
     return self.asend_query(data).get_response()
 
 class FileExporter(object):
-  """File exporter to export events to JSON file for batch import
+  """File exporter to write events to JSON file for batch import
 
   :param file_name: the destination file name
   """
@@ -502,7 +502,11 @@
   def create_event(self, event, entity_type, entity_id,
       target_entity_type=None, target_entity_id=None, properties=None,
       event_time=None):
-    """write event to the file"""
+    """Create an event and write to the file.
+
+    (please refer to EventClient's create_event())
+
+    """
     data = {
         "event": event,
         "entityType": entity_type,